# Ekaros

[![pypi-image]][pypi-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![license-image]][license-url]
[![codecov][codecov-image]][codecov-url]
[![jupyter-book-image]][docs-url]

<!-- Links: -->
[codecov-image]: https://codecov.io/gh/entelecheia/ekaros/branch/main/graph/badge.svg?token=PTZWYZT2X9
[codecov-url]: https://codecov.io/gh/entelecheia/ekaros
[pypi-image]: https://img.shields.io/pypi/v/ekaros
[license-image]: https://img.shields.io/github/license/entelecheia/ekaros
[license-url]: https://github.com/entelecheia/ekaros/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/entelecheia/ekaros?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/entelecheia/ekaros
[release-url]: https://github.com/entelecheia/ekaros/releases
[jupyter-book-image]: https://jupyterbook.org/en/stable/_images/badge.svg

[repo-url]: https://github.com/entelecheia/ekaros
[pypi-url]: https://pypi.org/project/ekaros
[docs-url]: https://ekaros.entelecheia.ai
[changelog]: https://github.com/entelecheia/ekaros/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/entelecheia/ekaros/blob/main/CONTRIBUTING.md
<!-- Links: -->

A Python Library for Generative AI Art

- Documentation: [https://ekaros.entelecheia.ai][docs-url]
- GitHub: [https://github.com/entelecheia/ekaros][repo-url]
- PyPI: [https://pypi.org/project/ekaros][pypi-url]

Ekaros is a creative and versatile Python library designed for crafting generative AI art, fostering the intersection of artificial intelligence and artistic expression. The name Ekaros is inspired by the Greek word Ἴκαρος (Icarus), symbolizing the limitless possibilities and aspirations in the realm of AI-driven creativity.

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [MIT License][license-url].
